@@ -149,6 +149,7 @@ class SetupReproEnv(Subcommand):
         self.inferred_platform = bool(self.platform is None)
         self.architecture = architecture.lower() if architecture else None
         self.variant = variant.lower() if variant else None
+
         self.versions = versions
         self.install_last_lts = install_last_lts
         self.install_last_continuous = install_last_continuous
@@ -231,6 +232,17 @@ class SetupReproEnv(Subcommand):
             LOGGER.info("Setting up version.", version=version)
             LOGGER.info("Fetching download URLs from Evergreen.")
 
+            variant = self.variant
+            try:
+                task = evergreen_conn.get_evergreen_task(self.evg_api, version)
+            except HTTPError as err:
+                if err.response.status_code != 404:
+                    LOGGER.warning("Unexpected error returned by Evergreen.", error=err)
+            else:
+                version = task.version_id
+                variant = task.build_variant
+                LOGGER.info("Found Evergreen version_id by the task_id.", version_id=version)
+
             try:
                 self.platform = (
                     infer_platform(self.edition, version)
@@ -242,7 +254,7 @@ class SetupReproEnv(Subcommand):
                     LOGGER.warning(
                         "Latest URLs are not available, falling back to getting the URLs for a specific version."
                     )
-                    urls_info = self.get_urls(version, self.variant)
+                    urls_info = self.get_urls(version, variant)
                 if not urls_info.urls:
                     LOGGER.warning(
                         "Specific version URLs are not available, falling back to getting the URLs from"
@@ -257,7 +269,7 @@ class SetupReproEnv(Subcommand):
 
                 bin_suffix = self._get_bin_suffix(version, urls["project_identifier"])
                 # Give each version a unique install dir
-                install_dir = os.path.join(self.install_dir, version)
+                install_dir = os.path.join(self.install_dir, urls_info.evg_version_id)
 
                 self.download_and_extract(urls, bin_suffix, install_dir)
                 downloaded_versions.append(urls_info.evg_version_id)
@@ -616,9 +628,9 @@ class SetupReproEnvPlugin(PluginInterface):
         parser.add_argument(
             "versions",
             nargs="*",
-            help="Accepts binary versions, `master`, full git commit hashes, evergreen version ids."
-            " Binary version examples: <major.minor>, 4.2, 4.4, 5.0 etc. If no version is specified"
-            " the last LTS and the last continuous versions will be installed.",
+            help="Accepts binary versions, `master`, full git commit hashes, evergreen version ids,"
+            " evergreen task ids. Binary version examples: <major.minor>, 4.2, 4.4, 5.0 etc. If no"
+            " version is specified the last LTS and the last continuous versions will be installed.",
         )
         parser.add_argument(
             "--installLastLTS",
